| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.CostExplorer.Types.CostAllocationTagStatusEntry
Description
Synopsis
- data CostAllocationTagStatusEntry = CostAllocationTagStatusEntry' {}
- newCostAllocationTagStatusEntry :: Text -> CostAllocationTagStatus -> CostAllocationTagStatusEntry
- costAllocationTagStatusEntry_tagKey :: Lens' CostAllocationTagStatusEntry Text
- costAllocationTagStatusEntry_status :: Lens' CostAllocationTagStatusEntry CostAllocationTagStatus
Documentation
data CostAllocationTagStatusEntry Source #
The cost allocation tag status. The status of a key can either be active or inactive.
See: newCostAllocationTagStatusEntry smart constructor.
Constructors
| CostAllocationTagStatusEntry' | |
Fields
| |
Instances
newCostAllocationTagStatusEntry Source #
Arguments
| :: Text | |
| -> CostAllocationTagStatus | |
| -> CostAllocationTagStatusEntry |
Create a value of CostAllocationTagStatusEntry with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:tagKey:CostAllocationTagStatusEntry', costAllocationTagStatusEntry_tagKey - The key for the cost allocation tag.
$sel:status:CostAllocationTagStatusEntry', costAllocationTagStatusEntry_status - The status of a cost allocation tag.
costAllocationTagStatusEntry_tagKey :: Lens' CostAllocationTagStatusEntry Text Source #
The key for the cost allocation tag.
costAllocationTagStatusEntry_status :: Lens' CostAllocationTagStatusEntry CostAllocationTagStatus Source #
The status of a cost allocation tag.