| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.CostExplorer.Types.CostCategoryInheritedValueDimension
Description
Synopsis
- data CostCategoryInheritedValueDimension = CostCategoryInheritedValueDimension' {}
- newCostCategoryInheritedValueDimension :: CostCategoryInheritedValueDimension
- costCategoryInheritedValueDimension_dimensionKey :: Lens' CostCategoryInheritedValueDimension (Maybe Text)
- costCategoryInheritedValueDimension_dimensionName :: Lens' CostCategoryInheritedValueDimension (Maybe CostCategoryInheritedValueDimensionName)
Documentation
data CostCategoryInheritedValueDimension Source #
When you create or update a cost category, you can define the
CostCategoryRule rule type as INHERITED_VALUE. This rule type adds
the flexibility to define a rule that dynamically inherits the cost
category value from the dimension value that's defined by
CostCategoryInheritedValueDimension. For example, suppose that you
want to dynamically group costs that are based on the value of a
specific tag key. First, choose an inherited value rule type, and then
choose the tag dimension and specify the tag key to use.
See: newCostCategoryInheritedValueDimension smart constructor.
Constructors
| CostCategoryInheritedValueDimension' | |
Fields
| |
Instances
newCostCategoryInheritedValueDimension :: CostCategoryInheritedValueDimension Source #
Create a value of CostCategoryInheritedValueDimension with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:dimensionKey:CostCategoryInheritedValueDimension', costCategoryInheritedValueDimension_dimensionKey - The key to extract cost category values.
$sel:dimensionName:CostCategoryInheritedValueDimension', costCategoryInheritedValueDimension_dimensionName - The name of the dimension that's used to group costs.
If you specify LINKED_ACCOUNT_NAME, the cost category value is based
on account name. If you specify TAG, the cost category value is based
on the value of the specified tag key.
costCategoryInheritedValueDimension_dimensionKey :: Lens' CostCategoryInheritedValueDimension (Maybe Text) Source #
The key to extract cost category values.
costCategoryInheritedValueDimension_dimensionName :: Lens' CostCategoryInheritedValueDimension (Maybe CostCategoryInheritedValueDimensionName) Source #
The name of the dimension that's used to group costs.
If you specify LINKED_ACCOUNT_NAME, the cost category value is based
on account name. If you specify TAG, the cost category value is based
on the value of the specified tag key.