| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.CostExplorer.Types.ResourceTag
Description
Synopsis
- data ResourceTag = ResourceTag' {}
- newResourceTag :: Text -> Text -> ResourceTag
- resourceTag_key :: Lens' ResourceTag Text
- resourceTag_value :: Lens' ResourceTag Text
Documentation
data ResourceTag Source #
The tag structure that contains a tag key and value.
Tagging is supported only for the following Cost Explorer resource types: AnomalyMonitor , AnomalySubscription , CostCategory .
See: newResourceTag smart constructor.
Constructors
| ResourceTag' | |
Instances
Arguments
| :: Text | |
| -> Text | |
| -> ResourceTag |
Create a value of ResourceTag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:ResourceTag', resourceTag_key - The key that's associated with the tag.
$sel:value:ResourceTag', resourceTag_value - The value that's associated with the tag.
resourceTag_key :: Lens' ResourceTag Text Source #
The key that's associated with the tag.
resourceTag_value :: Lens' ResourceTag Text Source #
The value that's associated with the tag.