| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.CostExplorer.Types.UpdateCostAllocationTagsStatusError
Description
Synopsis
- data UpdateCostAllocationTagsStatusError = UpdateCostAllocationTagsStatusError' {}
- newUpdateCostAllocationTagsStatusError :: UpdateCostAllocationTagsStatusError
- updateCostAllocationTagsStatusError_code :: Lens' UpdateCostAllocationTagsStatusError (Maybe Text)
- updateCostAllocationTagsStatusError_message :: Lens' UpdateCostAllocationTagsStatusError (Maybe Text)
- updateCostAllocationTagsStatusError_tagKey :: Lens' UpdateCostAllocationTagsStatusError (Maybe Text)
Documentation
data UpdateCostAllocationTagsStatusError Source #
Gives a detailed description of the result of an action. It's on each cost allocation tag entry in the request.
See: newUpdateCostAllocationTagsStatusError smart constructor.
Constructors
| UpdateCostAllocationTagsStatusError' | |
Instances
newUpdateCostAllocationTagsStatusError :: UpdateCostAllocationTagsStatusError Source #
Create a value of UpdateCostAllocationTagsStatusError with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:code:UpdateCostAllocationTagsStatusError', updateCostAllocationTagsStatusError_code - An error code representing why the action failed on this entry.
$sel:message:UpdateCostAllocationTagsStatusError', updateCostAllocationTagsStatusError_message - A message explaining why the action failed on this entry.
$sel:tagKey:UpdateCostAllocationTagsStatusError', updateCostAllocationTagsStatusError_tagKey - The key for the cost allocation tag.
updateCostAllocationTagsStatusError_code :: Lens' UpdateCostAllocationTagsStatusError (Maybe Text) Source #
An error code representing why the action failed on this entry.
updateCostAllocationTagsStatusError_message :: Lens' UpdateCostAllocationTagsStatusError (Maybe Text) Source #
A message explaining why the action failed on this entry.
updateCostAllocationTagsStatusError_tagKey :: Lens' UpdateCostAllocationTagsStatusError (Maybe Text) Source #
The key for the cost allocation tag.